@@ -41,6 +41,23 @@ class FirestoreClient(BaseClient):
     def get_collection(self, collection_name: str) -> CollectionReference:
         return self.firestore.collection(collection_name)
 
+    @classmethod
+    def delete_collection_fs(cls, coll_ref, batch_size):
+        docs = coll_ref.limit(batch_size).stream()
+        deleted = 0
+
+        for doc in docs:
+            print(f"Deleting doc {doc.id} => {doc.to_dict()}")
+            doc.reference.delete()
+            deleted = deleted + 1
+
+        if deleted >= batch_size:
+            return cls.delete_collection_fs(coll_ref, batch_size)
+
+    async def delete_collection(self, collection: str) -> None:
+        collection_ref = self.get_collection(collection)
+        self.delete_collection_fs(collection_ref, 50)
+
     def generate_id(self, collection_name: str) -> str:
         collection = self.get_collection(collection_name)
         return collection.document().id
@@ -66,7 +83,7 @@ class FirestoreClient(BaseClient):
 
         LOG.info(f"Insert Result: {result}")
 
-        return WriteResult(transform_results=[result])
+        return WriteResult(new_id=result[1].id, transform_results=[result])
 
     async def count(self, model: Type[DocumentDBModel], session: Any = None) -> int:
 
@@ -227,5 +244,5 @@ class FirestoreClient(BaseClient):
 
         return [model(**res) for res in results]
 
-    async def create_indexes(self, index=List[DBIndex]) -> Optional[List[str]]:
+    async def create_indexes(self, index: List[DBIndex], collection: str) -> Optional[List[str]]:
         return None
